class BoxCoaterEventsController < ApplicationController
  # This is a proxy controller, all the actions go back to an Rx-Data controller

  def index
    data = RxModule::Communicator.call_module_method_internal('rx_data', external_base_url, :get, params.as_json)
    BoxCoaterEvent.add_requires_action(data[:models])
    render json: data
  rescue StandardError => e
    render status: :internal_server_error, json: { error: 'unexpected error.', details: e }
  end

  def show
    data = RxModule::Communicator.call_module_method_internal('rx_data', "#{external_base_url}/#{params[:id]}", :get)
    BoxCoaterEvent.add_requires_action(data)
    render json: data
  rescue StandardError => e
    render status: :internal_server_error, json: { error: 'unexpected error.', details: e }
  end

  def update
    params = update_params
    unless params[:operator_note].nil?
      if params[:reporting_category].nil?
        params[:reporting_category] = OperatorNote.find_by(code: update_params[:operator_note])&.resolved_category&.report_code
      end
    end
    render json: RxModule::Communicator.call_module_method_internal('rx_data', "#{external_base_url}/#{params[:id]}", :put, params)
  rescue StandardError => e
    render status: :internal_server_error, json: { error: 'unexpected error.', details: e }
  end

  private

  def external_base_url
    '/api/box_coater_events'
  end

  def update_params
    params.require(:box_coater_event).permit(:id, :operator_note, :recipe, :reporting_category, batch: {})
  end
end