class EerTrackingStationsController < ApplicationController
  include PushTargetResponse
  protect_with("EerTrackingStation", "EerTrackingStation")
  also_protect_with([{id: "engineering_lockout", name: "EngineeringLockout", controller_methods: :engineering_lockout}])

  def self.set_target_before
    super + %i[current_state engineering_lockout]
  end

  model_data_store(EerTrackingStation)

  def show
    @event = @model.coater_current_event
    render :show
  rescue StandardError => e
    render status: :internal_server_error, json: { error: 'unexpected error.', details: e }
  end

  def index
    machine_ids = @models.pluck(:rx_data_machine_id)
    events = EerTrackingStation.current_event_for_machines(machine_ids)
    @models.each do |model|
      machine_id = model.rx_data_machine_id
      current_event = events.find { |e| e[:machine_id] == machine_id }
      model.set_event(current_event)
    end
    @models
  end

  def create
    @model = model_type.new(__mssql_model_params__.except(:id))

    begin
      @model.register
    rescue StandardError
      return fail_connect_rx_data
    end

    if @model.save
      render json: @model, status: :created, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def destroy
    begin
      @model.unregister
    rescue StandardError
      return fail_connect_rx_data
    end

    if @model.destroy
      head :no_content
    else
      render json: @model.errors, status: :conflict
    end
  end

  def engineering_lockout
    params = lockout_params
    @event = @model.set_engineer_lockout_external(params[:lock])
    render :show
  rescue StandardError
    fail_connect_rx_data
  end

  # Handles push events from Rx-Data for Box Coater Events
  def update_ongoing_event
    unless params[:machine_id].nil?
      tracking_station = EerTrackingStation.find_by(rx_data_machine_id: params[:machine_id])
      unless tracking_station.nil?
        ActionCable.server.broadcast 'everything', {
          model: JSON.parse(tracking_station.to_json(params)),
          class: tracking_station.broadcast_class_name,
          action: :update,
          timestamp: Time.now.to_i
        }
      end
    end
    send_push_response
  end

  private

  def fail_connect_rx_data
    render json: { error: 'Error while connecting to Rx-Data. Consult logs for more information.' }, status: :unprocessable_entity
  end

  def model_params
    params.fetch(:eer_tracking_station).permit(:name, :machine_sn, :door_open_max_time, :door_closed_max_time, :rx_data_machine_id, :operator_note_group_ids => [])
  end

  def lockout_params
    params.permit(:lock)
  end
end
