class MachineStatesController < ApplicationController
  # Proxy Controller to Rx-Data

  include PushTargetResponse

  def index
    data = RxModule::Communicator.call_module_method_internal('rx_data', '/api/machines/status_all', :get)
    render json: extract_box_coater_machine_states(data)
  rescue StandardError => e
    render status: :internal_server_error, json: { error: 'unexpected error.', details: e }
  end

  def update_machine_state
    data = machine_state_params
    ActionCable.server.broadcast 'everything', {
      model: JSON.parse(data.to_json),
      class: 'MachineState',
      action: :update,
      timestamp: Time.parse(data[:time]).to_i
    }
    send_push_response
  end

  private

  def extract_box_coater_machine_states(data)
    machine_states = []
    data.each do |sn, machine|
      station = EerTrackingStation.find_by(rx_data_machine_id: machine[:machine_id])
      next if station.nil?

      # NOTE: we use the machine id as the machine state Id so it can be updated later
      machine_states << { id: machine[:machine_id], machine_id: machine[:machine_id], state: machine[:status], comment: machine[:comment] }
    end
    machine_states
  end

  def machine_state_params
    {
      id: params[:machine_id],
      machine_id: params[:machine_id],
      state: params[:state],
      comment: params[:comment],
      time: params[:time]
    }
  end
end
