import * as React from "react";
import {observer} from "mobx-react-lite";
import {BoxCoaterEventModel} from "../../../stores/BoxCoaterEventStore";
import {Conditional, IfFalse, IfTrue, ModelInput, ModelProvider} from "@rx-suite/ui";
import {Box, Grid, makeStyles, Typography} from "@material-ui/core";
import {Warning} from "@material-ui/icons";
import {t, Trans} from "@lingui/macro";
import {grey} from "@material-ui/core/colors";
import {BoxCoaterBatchModel} from "../../../stores/BoxCoaterBatchStore";
import {ActionRequiredBadge} from "../bread_model/ActionRequiredBadge";

type BoxCoaterBatchEditFormProps = {
    model: BoxCoaterEventModel
}

const useStyles = makeStyles((theme) => ({
    infoIcon: {
        marginRight: theme.spacing(1),
        color: grey[600]
    },
    infoMessageWrapper: {
        marginLeft: theme.spacing(1),
        minHeight: '100px',
        color: grey[600]
    }
}));

export const BoxCoaterBatchEditForm: React.FunctionComponent<BoxCoaterBatchEditFormProps> = observer(({model}) => {
    const classes = useStyles();

    return (
        <React.Fragment>
            <Grid container alignItems={'center'}>
                <Box mr={1}>
                    <Typography variant={'h5'}><Trans>Batch Information</Trans></Typography>
                </Box>
                {model.batch && model.batch.requires_lens_entry && <ActionRequiredBadge text={t`Lens Data Missing`}/>}
            </Grid>
            <Typography variant={'caption'}><Trans>Note: batch information can only be edited if it was not previously completed.</Trans></Typography>
            <Conditional condition={model.batch !== null}>
                <IfFalse>
                    <Grid container className={classes.infoMessageWrapper} alignItems={'center'}>
                        <Warning className={classes.infoIcon}/><Typography variant={'h6'}>{t`No batch information found`}</Typography>
                    </Grid>
                </IfFalse>
                <IfTrue>
                    {model.batch &&
                        <>
                            <ModelProvider value={model}>
                                <ModelInput name={'recipe'} disabled={model.recipe != null}/>
                            </ModelProvider>
                            <ModelProvider value={model.batch as BoxCoaterBatchModel}>
                                <ModelInput
                                    label={t`Batch Id`}
                                    name={'batch_id'}
                                    disabled={true}
                                />
                                <ModelInput
                                    label={t`Number of lenses in batch`}
                                    name={'lens_count'}
                                    type={'number'}
                                    inputProps={
                                        {
                                            min: 0
                                        }
                                    }
                                    disabled={model.batch.lens_count !== null}
                                />
                                <ModelInput
                                    label={t`Number of empty holes`}
                                    name={'empty_holes_count'}
                                    type={'number'}
                                    inputProps={
                                        {
                                            min: 0
                                        }
                                    }
                                    disabled={model.batch.empty_holes_count !== null}
                                />
                            </ModelProvider>
                        </>
                    }
                </IfTrue>
            </Conditional>
        </React.Fragment>
    )
})
