import * as React from "react";
import {observer} from "mobx-react-lite";
import {BoxCoaterEventModel} from "../../../stores/BoxCoaterEventStore";
import {ButtonField, Conditional, IfFalse, IfTrue, ModelForm, sendEnqueueSnackbar} from "@rx-suite/ui";
import {Grid, makeStyles} from "@material-ui/core";
import {t} from "@lingui/macro";
import {OperatorNoteModel} from "../../../stores/OperatorNoteStore";
import {useSnackbar} from "notistack";

type BoxCoaterEvenFormSubmitButtonProps = {
    model: BoxCoaterEventModel
}


export const BoxCoaterEvenFormSubmitButton: React.FunctionComponent<BoxCoaterEvenFormSubmitButtonProps> = observer(({model}) => {
    const {enqueueSnackbar} = useSnackbar();

    const requiresNoteEntry = model.requires_operator_note || (model.batch !== null && model.batch.requires_lens_entry);

    const [isSubmitting, setIsSubmitting] = React.useState<boolean>(false);

    const handleUpdateEvent = React.useCallback(async () => {
        setIsSubmitting(true);

        if(model.batch){
            model.batch.viewModel.submit();
        }
        model.viewModel.submit();

        try{
            await model.submitEventInformation();
            sendEnqueueSnackbar(t`Event information successfully updated.`, {variant: "success"}, enqueueSnackbar)
        }catch (e) {
            console.error(e);
            sendEnqueueSnackbar(t`Event while updating event information updated.`, {variant: "error"}, enqueueSnackbar)
        }

        setIsSubmitting(false);
    }, [model]);

    if(!requiresNoteEntry){
        return null
    }

    return (
        <ButtonField
            text={t`Update Event`}
            onClick={handleUpdateEvent}
            variant={"contained"}
            color={"secondary"}
            loading={isSubmitting}
        />
    )
})
