import * as React from "react";
import {observer} from "mobx-react-lite";
import {BoxCoaterEventModel} from "../../../stores/BoxCoaterEventStore";

import {Box, Grid, makeStyles, Typography} from "@material-ui/core";

import {t, Trans} from "@lingui/macro";
import {grey} from "@material-ui/core/colors";
import {OperatorNoteGroupStore} from "../../../stores/OperatorNoteGroupStore";
import {OperatorNoteStore} from "../../../stores/OperatorNoteStore";
import {Conditional, IfFalse, IfTrue, ModelProvider, ModelSelect, SelectField} from "@rx-suite/ui";
import {InputField} from "@rx-suite/ui";
import {Info} from "@material-ui/icons";
import {ActionRequiredBadge} from "../bread_model/ActionRequiredBadge";


type BoxCoaterOperatorNoteEditFormProps = {
    model: BoxCoaterEventModel
}

const useStyles = makeStyles((theme) => ({
    infoIcon: {
        marginRight: theme.spacing(1),
        color: grey[600]
    },
    infoMessageWrapper: {
        marginLeft: theme.spacing(1),
        minHeight: '100px',
        color: grey[600]
    }
}));

export const BoxCoaterOperatorNoteEditForm: React.FunctionComponent<BoxCoaterOperatorNoteEditFormProps> = observer(({model}) => {
    const classes = useStyles();

    React.useEffect(() => {
        OperatorNoteGroupStore.getAll();
        OperatorNoteStore.getAll();
    }, [])

    const selectedNote = model.operator_note ? OperatorNoteStore.models.find(n => n.code == model.operator_note) : null;
    const [selectedGroup, setSelectedGroup] = React.useState<number>(selectedNote ? selectedNote.operator_note_group_id : -1);

    const noteGroupOptions = OperatorNoteGroupStore.models.map((group) => {
        return {label: group.name, value: group.id}
    })

    const noteOptions = OperatorNoteStore.models
        .filter(n =>
            // Filter by note group
            n.operator_note_group_id === selectedGroup
        )
        .filter(n => {
            // Then filter by event type
            if(model.is_door_open_event){
                return n.display_during_door_open;
            } else if(model.is_door_closed_event){
                return n.display_during_door_closed;
            } else{
                return false;
            }
        })
        .sort((a,b) => a.code.localeCompare(b.code))
        .map((note) => {

            return {label: note.code, value: note.code}
        })






    const displayOperatorNoteEntry = model.requires_operator_note || model.operator_note != null


    return (
        <React.Fragment>
            <Grid container alignItems={'center'}>
                <Box mr={1}>
                    <Typography variant={'h5'}><Trans>Performance Notes</Trans></Typography>
                </Box>
                {model.requires_operator_note && <ActionRequiredBadge text={t`Performance Note Missing`}/>}
            </Grid>
            <Typography variant={'caption'}><Trans>Note: a performance note can only be entered if one has not been previously entered.</Trans></Typography>
            <ModelProvider value={model}>
                <InputField
                    name={'event_duration'}
                    label={'Event Duration'}
                    value={model.resolved_duration}
                    disabled={true}
                />
                <Conditional condition={displayOperatorNoteEntry}>
                    <IfTrue>
                        <SelectField
                            label={t`Code Group`}
                            options={noteGroupOptions}
                            onChange={(name, value) => setSelectedGroup(value)}
                            value={selectedGroup}
                            disabled={model.operator_note !== null}
                        />

                        <ModelSelect
                            label={t`Operation Code`}
                            name={'operator_note'}
                            options={noteOptions}
                            disabled={model.operator_note !== null}
                        />
                    </IfTrue>
                    <IfFalse>
                        <Grid container className={classes.infoMessageWrapper} alignItems={'center'}>
                            <Info className={classes.infoIcon}/><Typography variant={'h6'}>{t`This event does not require a performance note.`}</Typography>
                        </Grid>
                    </IfFalse>
                </Conditional>
            </ModelProvider>
        </React.Fragment>
    )
})
