import * as React from "react";
import {observer} from "mobx-react-lite";
import {ColorPicker} from "material-ui-color";
import {isArrayLike} from "@rx-suite/data";
import {EerCategoryModel} from "../../stores/EerCategoryStore";
import {Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";

type EerCategoryColorPickerProps = {
    model: EerCategoryModel,
    includeLabel?: boolean
}

const useStyles = makeStyles(theme => ({
    wrapper: {
        display: "flex",
        alignItems: 'center'
    }
}));

export const EerCategoryColorPicker: React.FunctionComponent<EerCategoryColorPickerProps> = observer(({model, includeLabel= true}) => {

    const classes = useStyles();
    const [workingColor, setWorkingColor] = React.useState(model.viewModel.color);
    React.useEffect(() => {
        setWorkingColor(model.viewModel.color);
    }, [setWorkingColor, model.viewModel.color])

    const handleColorChange = React.useCallback(newColor => {
        if (newColor.error || (!(isArrayLike(newColor.raw) && (newColor.raw.length < 6)))) {
            setWorkingColor(newColor.raw); // if the user types in a Hex code we need to allow partial entry.  If they click directly on the picker grid then raw will be an array of values that we can extract a complete hex from
        } else if (newColor.hex) {
            const withHash = newColor.hex[0] === '#' ? newColor.hex : `#${newColor.hex}`
            setWorkingColor(withHash)
            model.nestedAssignment('color', withHash);
        }
    }, [model, setWorkingColor]);

    return (
        <div className={classes.wrapper}>
            {includeLabel && <Typography><Trans>Category Color</Trans></Typography>}
            <ColorPicker value={workingColor} onChange={handleColorChange} disableAlpha hideTextfield />
        </div>
    )
})
