import * as React from 'react'
import {observer} from "mobx-react-lite";
import {makeStyles, Typography} from "@material-ui/core";
import {Conditional, IfFalse, IfTrue} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {faExclamationCircle, faLock, faLockOpen} from "@rx-suite/pro-solid-svg-icons";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {BoxCoaterEventModel} from "../../stores/BoxCoaterEventStore";

const useStyles = makeStyles(theme => ({
    lockedStyle: {
        color: theme.palette.error.main
    },
    notLockedStyle: {
        color: theme.palette.success.main
    },
    divWrapper: {
        textAlign: "center"
    }
}));

type LockoutProp = {
    currentEvent: BoxCoaterEventModel | null;
}
export const WorkstationLockoutStatus: React.FunctionComponent<LockoutProp> = observer(({currentEvent}) => {
    const classes = useStyles();

    if(!currentEvent){
        return (
            <div className={classes.divWrapper}>
                <Typography><FontAwesomeIcon icon={faExclamationCircle}/> {t`Status Unknown`}</Typography>
            </div>
        )
    }

    return (
        <div className={classes.divWrapper}>
            <Conditional condition={currentEvent.is_engineering_lockout_event}>
                <IfTrue>
                    <Typography><FontAwesomeIcon icon={faLock} className={classes.lockedStyle}/> {t`In Lockout`}</Typography>
                </IfTrue>
                <IfFalse>
                    <Typography><FontAwesomeIcon icon={faLockOpen} className={classes.notLockedStyle}/> {t`Not in Lockout`}</Typography>
                </IfFalse>
            </Conditional>
        </div>
    )
})