import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField, ModelInput, ModelProvider, sendEnqueueSnackbar, WorkstationGenericWrapper} from "@rx-suite/ui";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {useSnackbar} from "notistack";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";

type TrackingStationLensEntryProps = {
    event: BoxCoaterEventModel
}

const useStyles = makeStyles(() => ({
    inputWrapper: {
        width: '100%',
        maxWidth: '500px'
    }
}));

export const TrackingStationLensEntry: React.FunctionComponent<TrackingStationLensEntryProps> = observer(({event}) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles();

    const [isProcessing, setIsProcessing] = React.useState(false);

    const handleLensEntrySubmit = React.useCallback(async () => {
        if(!event.batch){
            return
        }

        setIsProcessing(true);

        event.batch.viewModel.submit();
        try{
            await event.submitEventInformation();
            sendEnqueueSnackbar(t`Lenses information successfully saved.`, {variant: "success"}, enqueueSnackbar)
        }catch (e) {
            console.error(e);
            sendEnqueueSnackbar(t`Error while saving lenses information !`, {variant: "error"}, enqueueSnackbar)
        }

        setIsProcessing(false);
    }, [event]);

    if(!event.batch){
        return null;
    }

    return (
        <React.Fragment>
            <ModelProvider value={event.batch}>
                <WorkstationGenericWrapper>
                    <Typography variant={'h5'} style={{textAlign:'center'}}>
                        <Trans>Please enter the number of lenses and empty holes in the batch.</Trans>
                    </Typography>
                    <Grid container justifyContent={'center'} >
                        <div className={classes.inputWrapper}>
                            <ModelInput
                                label={t`Number of lenses in batch`}
                                name={'lens_count'}
                                type={'number'}
                                inputProps={
                                    {
                                        min: 0
                                    }
                                }
                            />
                            <ModelInput
                                label={t`Number of empty holes`}
                                name={'empty_holes_count'}
                                type={'number'}
                                inputProps={
                                    {
                                        min: 0
                                    }
                                }
                            />
                            <ButtonField
                                text={t`Update Batch Information`}
                                onClick={handleLensEntrySubmit}
                                variant={"contained"}
                                color={"secondary"}
                                disabled={event.batch.viewModel.lens_count === null || event.batch.viewModel.empty_holes_count === null}
                                loading={isProcessing}
                            />
                        </div>
                    </Grid>
                </WorkstationGenericWrapper>
            </ModelProvider>
        </React.Fragment>
    )
})
