import * as React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles, Typography} from "@material-ui/core";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {t} from "@lingui/macro";

type TrackingStationReasonDoorMessageProps = {
    event: BoxCoaterEventModel;
    elapsedTime: number;
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        textAlign: 'center'
    }
}));

export const TrackingStationReasonDoorMessage: React.FunctionComponent<TrackingStationReasonDoorMessageProps> = observer(({event, elapsedTime}) => {
    const classes = useStyles();
    const settings = SystemSettingStore.selectedModel as SystemSettingModel;

    if(!settings) { return null }

    const resolvedTime = React.useCallback((elapsedTime: number)=> {
        const minutes = Math.floor(elapsedTime/60);

        return minutes.toString() + " " + t`minutes`;
    }, []);

    const message = React.useMemo(() => {
        const type = event.is_door_open_event ? 'OPENED' : 'CLOSED';

        return  t`Please select a reason why the machine door has been ${type} for longer than ${resolvedTime(elapsedTime)}.`
    }, [event, elapsedTime])

    return (
        <div className={classes.wrapper}>
            <Typography variant={'h5'}>{message}</Typography>
        </div>
    )
})
