import * as React from "react";
import {observer} from "mobx-react-lite";
import {Divider, Grid, List, makeStyles, Typography} from "@material-ui/core";
import {Conditional, IfFalse, IfTrue, PaddedPaper, WorkstationGenericWrapper} from "@rx-suite/ui";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";
import {t} from "@lingui/macro";
import {Warning} from "@material-ui/icons";
import {BoxCoaterRecipeStore} from "../../../../stores/BoxCoaterRecipeStore";

type TrackingStationBatchInfoPanelProps = {
    event: BoxCoaterEventModel;
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        width: '18%',
        marginRight: theme.spacing(1),
        overflow: "hidden"
    },
    warningMessageWrapper: {
        height: '100px'
    },
    warningIcon: {
      marginRight: theme.spacing(1)
    },
    listWrapper: {
        width: '100%'
    },
    listLabel: {
        fontWeight: 600
    }
}));

export const TrackingStationBatchInfoPanel: React.FunctionComponent<TrackingStationBatchInfoPanelProps> = observer(({event}) => {
    const classes = useStyles();

    const panelData = React.useCallback((event) => {
        const missingData = t`unknown`;
        const notEntered = t`waiting user input`;

        let recipe = null;
        if(event.recipe){
            const recipeData = BoxCoaterRecipeStore.models.find(r => r.recipe_code == event.recipe);

            // If the recipe has no name, use the code
            if(recipeData){
                recipe = recipeData.name;
            }else{
                recipe = event.recipe;
            }
        }

        return [
            { label: t`Batch Id`,           value: event.batch?.batch_id ? String(event.batch.batch_id) : missingData },
            { label: t`Recipe`,             value: recipe ? String(recipe) : missingData },
            { label: t`Crystal Life`,       value: event.batch?.crystal_life ? String(event.batch.crystal_life) : missingData },
            { label: t`Lens Count`,         value: event.batch?.lens_count ? String(event.batch.lens_count) : notEntered },
            { label: t`Empty Holes Count`,  value: event.batch?.empty_holes_count ? String(event.batch.empty_holes_count) : notEntered }
        ]
    }, [BoxCoaterRecipeStore.models]);

    if(event.is_engineering_lockout_event){
        return null;
    }

    return (
        <WorkstationGenericWrapper WrapperComponent={React.Fragment}>
            <PaddedPaper className={classes.wrapper}>
                <Typography variant={'h5'}>{t`Batch Information`}</Typography>
                <Conditional condition={event.is_door_open_event}>
                    <IfTrue>
                        <Grid container className={classes.warningMessageWrapper} justifyContent={'center'} alignItems={'center'}>
                            <Warning className={classes.warningIcon}/><Typography variant={'h6'}>{t`No batch currently loaded`}</Typography>
                        </Grid>
                    </IfTrue>
                    <IfFalse>
                        <Grid container>
                            <List className={classes.listWrapper}>
                                {
                                    panelData(event).map(field => {
                                        return (
                                            <React.Fragment>
                                                <Grid container justifyContent={'space-between'} alignItems={'center'}>
                                                    <Grid item><Typography variant={'subtitle1'} className={classes.listLabel}>{field.label}</Typography></Grid>
                                                    <Grid item><Typography variant={'subtitle2'}>{field.value}</Typography></Grid>
                                                </Grid>
                                                <Divider/>
                                            </React.Fragment>
                                        )
                                    })
                                }
                            </List>
                        </Grid>
                    </IfFalse>
                </Conditional>
            </PaddedPaper>
        </WorkstationGenericWrapper>
    )
})
