import * as React from "react";
import {LinearProgress} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {green, orange, red} from "@material-ui/core/colors";
import {useEffect} from "react";
import {observer} from "mobx-react-lite";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";

export type BoxCoaterEventTimerProps = {
    event: BoxCoaterEventModel,
    maxTime: number, //expressed in seconds
}

const useStyles = makeStyles((theme) => ({
    container: {
        position: 'relative'
    },
    bar: {
        height: '100px',
        margin: theme.spacing(1),
        marginBottom: 0
    },
    timer: {
        position: 'absolute',
        zIndex: 1,
        left: '45%',
        top: '20%',
        fontSize: '3rem'
    },
    ok: {
        "& $bar": {
            "& .MuiLinearProgress-barColorPrimary": {
                backgroundColor: green[300]
            }
        },
        "& $timer": {
            color: green[900]
        }
    },
    warn: {
        "& $bar": {
            "& .MuiLinearProgress-barColorPrimary": {
                backgroundColor: orange[300]
            }
        },
        "& $timer": {
            color: orange[900]
        }
    },
    danger: {
        "& $bar": {
            "& .MuiLinearProgress-barColorPrimary": {
                backgroundColor: red[300]
            }
        },
        "& $timer": {
            color: red[900]
        }
    }
}));

export const BoxCoaterEventTimer: React.FunctionComponent<BoxCoaterEventTimerProps> = observer(({event, maxTime}) => {
    const classes = useStyles();

    const [timeProgress, setTimeProgress] = React.useState<Number>(event.ongoing_duration);

    useEffect(() => {
        const timer = setInterval( () => {
            setTimeProgress(event.ongoing_duration);
        }, 1000);
        return () => {
            clearInterval(timer);
        };
    }, [event])

    const progressPercent = React.useCallback((progress, max) => {
        let value = (progress / max) * 100;
        if(value > 100) return 100;
        if(value < 0) return 0;
        return value
    }, []);

    const progressStyle = React.useCallback((progress) => {
        if(progress >= 80){
            return classes.danger
        }else if(progress >= 50){
            return classes.warn
        }else{
            return classes.ok
        }
    }, [])

    const splitDuration = React.useCallback((duration) => {
        if(duration < 0){
            return {hours: "00", minutes: "00", seconds: "00"}
        }

        const hoursVal = Math.floor(duration / 3600)
        const minutesVal =  Math.floor((duration - (hoursVal * 3600)) / 60);
        const secondsVal = Math.floor(duration - (hoursVal * 3600) - (minutesVal * 60));

        return {
            hours: hoursVal.toString().padStart(2, '0'),
            minutes: minutesVal.toString().padStart(2, '0'),
            seconds: secondsVal.toString().padStart(2, '0')
        }
    }, []);

    const progress = progressPercent(timeProgress, maxTime);
    const {hours, minutes, seconds} = splitDuration(timeProgress);

    return (
        <div className={`${classes.container} ${progressStyle(progress)}`}>
            <div className={classes.timer}>
                {`${hours}:${minutes}:${seconds}`}
            </div>
            <LinearProgress className={classes.bar} variant="determinate" value={progress} />
        </div>
    )
});