import * as React from "react";
import {Grid, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {observer} from "mobx-react-lite";
import {Conditional, IfFalse, IfTrue, PaddedPaper, WorkstationGenericWrapper} from "@rx-suite/ui";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";
import {TrackingStationTimerDoorMessage} from "./TrackingStationTimerDoorMessage";
import {TextBadge} from "../../../generic/TextBadge";
import {BoxCoaterEventTimer} from "./BoxCoaterEventTimer";
import {Warning} from "@material-ui/icons";
import {t} from "@lingui/macro";
import {grey} from "@material-ui/core/colors";

export type TrackingStationEventTimerPanelProps = {
    event: BoxCoaterEventModel,
    eventMaxDuration: number, //expressed in seconds
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        width: '80%'
    },
    eventInfo: {
      marginTop: theme.spacing(0.5)
    },
    warningMessageWrapper: {
        height: '100%',
        color: grey[700]
    },
    warningIcon: {
        fontSize: '3rem',
        marginRight: theme.spacing(1),
    },
}));

export const TrackingStationEventTimerPanel: React.FunctionComponent<TrackingStationEventTimerPanelProps> = observer(({event, eventMaxDuration, timesUpCB}) => {
    const classes = useStyles();

    return (
        <WorkstationGenericWrapper WrapperComponent={React.Fragment}>
            <PaddedPaper className={classes.wrapper}>
                <Conditional condition={event.is_engineering_lockout_event}>
                    <IfTrue>
                        <Grid container className={classes.warningMessageWrapper} justifyContent={'center'} alignItems={'center'}>
                            <Warning className={classes.warningIcon}/><Typography variant={'h3'}>{t`Machine is currently in an engineering lockout.`}</Typography>
                        </Grid>
                    </IfTrue>
                    <IfFalse>
                        <BoxCoaterEventTimer event={event} maxTime={eventMaxDuration}/>
                        <Grid className={classes.eventInfo} container>
                            <TrackingStationTimerDoorMessage event={event} eventMaxDuration={eventMaxDuration}/>
                        </Grid>
                    </IfFalse>
                </Conditional>
            </PaddedPaper>
        </WorkstationGenericWrapper>
    )
});