import * as React from "react";
import {observer} from "mobx-react-lite";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {t} from "@lingui/macro";
import moment from "moment";
import {Warning} from "@material-ui/icons";
import {Conditional, IfFalse, IfTrue} from "@rx-suite/ui";

type TrackingStationTimerDoorMessageProps = {
    event: BoxCoaterEventModel;
    eventMaxDuration: number;
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        marginLeft: theme.spacing(1),
        marginRight: theme.spacing(1),
        width: '100%'
    },
    warningIcon: {
        fontSize: '1rem',
        marginRight: theme.spacing(0.5),
    },
}));

export const TrackingStationTimerDoorMessage: React.FunctionComponent<TrackingStationTimerDoorMessageProps> = observer(({event, eventMaxDuration}) => {
    const classes = useStyles();
    const settings = SystemSettingStore.selectedModel as SystemSettingModel;

    if(!settings) { return null }

    const message = React.useMemo(() => {
        if(event.is_door_open_event){
            return t`Machine door is OPENED since` + " " + settings.printTimeDate(moment(event.time));
        }else{
            return t`Machine door is CLOSED since` + " " + settings.printTimeDate(moment(event.time));
        }
    }, [event])

    const resolvedTime = React.useCallback((elapsedTime: number)=> {
        const minutes = Math.floor(elapsedTime/60);

        return minutes.toString() + " " + t`minutes`;
    }, []);

    return (
        <div className={classes.wrapper}>
            <Grid container alignItems={'center'} justifyContent={'space-between'}>
                <Grid item>
                    <Typography variant={'subtitle1'}>{message}</Typography>
                </Grid>
                <Conditional condition={event.is_door_closed_event && event.recipe === null}>
                    <IfTrue>
                        <Grid item>
                            <Grid container justifyContent={'center'} alignItems={'center'}>
                                <Warning className={classes.warningIcon}/><div>{t`Recipe duration unknown, using default target of ${resolvedTime(eventMaxDuration)}.`}</div>
                            </Grid>
                        </Grid>
                    </IfTrue>
                    <IfFalse>
                        <div>{t`Target time: ${resolvedTime(eventMaxDuration)}`}</div>
                    </IfFalse>
                </Conditional>
            </Grid>
        </div>
    )
})
