import React from "react";
import {observer} from "mobx-react-lite";
import {makeStyles, Switch} from "@material-ui/core";
import {useSnackbar} from "notistack";
import {EerTrackingStationModel} from "../../../../stores/EerTrackingStationStore";
import {t} from "@lingui/macro";
import {ButtonField, Conditional, IfFalse, IfTrue, sendEnqueueSnackbar} from "@rx-suite/ui";
import {BoxCoaterEventModel} from "../../../../stores/BoxCoaterEventStore";

const useStyles = makeStyles(theme => ({
    lockedStyle: {
        color: theme.palette.error.main,
    }
}));

type EngineeringLockoutProp = {
    station: EerTrackingStationModel;
}

export const EngineeringLockoutButton: React.FunctionComponent<EngineeringLockoutProp> = observer(({station}) => {
    const classes = useStyles();
    const {enqueueSnackbar} = useSnackbar();

    const [isProcessing, setIsProcessing] = React.useState(false);



    const handleToggle = React.useCallback(async ()=> {
        setIsProcessing(true)

        if(!station.current_event){
            return null;
        }

        const isStarting = !station.current_event.is_engineering_lockout_event;

        try{
            await station.toggleEngineeringLockout();
            const stationName = station.name
            const msg = isStarting ? t`Engineering Lockout started for ${stationName}.` : t`Engineering Lockout stopped for ${stationName}.`
            sendEnqueueSnackbar(msg, {variant: "success"}, enqueueSnackbar)
        }catch (e) {
            const msg = isStarting ? t`Error while starting Engineering Lockout.` : t`Error while stopping Engineering Lockout.`
            sendEnqueueSnackbar(msg, {variant: "error"}, enqueueSnackbar)
            console.error(e);
        }
        setIsProcessing(false)
    }, [station])

    if(!station.current_event){
        return null;
    }

    return (
        <Conditional condition={station.current_event.is_engineering_lockout_event}>
            <IfTrue>
                <ButtonField
                    text={t`Stop Engineering Lockout`}
                    onClick={handleToggle}
                    className={classes.lockedStyle}
                    color={'primary'}
                    variant={'contained'}
                    loading={isProcessing}/>
            </IfTrue>
            <IfFalse>
                <ButtonField
                    text={t`Start Engineering Lockout`}
                    onClick={handleToggle}
                    color={'primary'}
                    variant={'contained'}
                    loading={isProcessing}
                />
            </IfFalse>
        </Conditional>
    )
})
