import * as React from "react";
import {observer} from "mobx-react-lite";
import {Grid, LinearProgress, makeStyles, Typography} from "@material-ui/core";
import {MachineModel} from "../../../../stores/MachineStore";
import {MachineStateIndicatorDot} from "./MachineStateIndicatorDot";
import {Conditional, IfFalse, IfTrue, PaddedPaper, WorkstationGenericWrapper} from "@rx-suite/ui";
import {EerTrackingStationModel} from "../../../../stores/EerTrackingStationStore";
import {MachineStateStore} from "../../../../stores/MachineStateStore";

type TrackingStationMachineInfoPanelProps = {
    station: EerTrackingStationModel;
    machine: MachineModel;
}

const useStyles = makeStyles((theme) => ({
    wrapper: {
        width: '18%',
        marginRight: theme.spacing(1)
    }
}));

export const TrackingStationMachineInfoPanel: React.FunctionComponent<TrackingStationMachineInfoPanelProps> = observer(({station, machine}) => {
    const classes = useStyles();

    const machineState = MachineStateStore.models.find(ms => ms.machine_id === station.rx_data_machine_id);

    return (
        <WorkstationGenericWrapper WrapperComponent={React.Fragment}>
            <PaddedPaper className={classes.wrapper}>
                <Conditional condition={machineState === null}>
                    <IfTrue>
                        <LinearProgress/>
                    </IfTrue>
                    <IfFalse>
                        {machineState &&
                            <Grid container>
                                <Grid item><MachineStateIndicatorDot state={machineState.resolved_state}/></Grid>
                                <Grid item>
                                    <Typography variant={'h5'}>{machineState.resolved_state}</Typography>
                                    <Typography variant={'subtitle1'}>{machineState.comment}</Typography>
                                </Grid>
                            </Grid>
                        }
                    </IfFalse>
                </Conditional>
            </PaddedPaper>
        </WorkstationGenericWrapper>
    )
})