import {Conditional, FormProps, IfFalse, IfTrue, ModelForm, ModelInput, ModelProvider, ModelSelect} from "@rx-suite/ui";
import {Model} from "@rx-suite/data/build";
import React from "react";
import {observer} from "mobx-react-lite";
import {
    Button,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
} from "@material-ui/core";
import {EerCategoryStore} from "../../stores/EerCategoryStore";
import {t, Trans} from "@lingui/macro";

interface OperatorNoteFormProps extends FormProps{
    open: boolean,
    handleSubmit: (model:Model) => void,
    handleClose: () => void
}

export const OperatorNoteForm: React.FunctionComponent<OperatorNoteFormProps> = observer(({model, open, handleSubmit, handleClose}) => {
    const categoryOptions = EerCategoryStore.models.map((category) => {
        return {label: category.name, value: category.id}
    });

    const displayOptions = [
        {label: t`Door Close and Door Open`, value: 'both'},
        {label: t`Door Close only`, value: 'closed'},
        {label: t`Door Open only`, value: 'open'}
    ];

    return (
        <div>
            <ModelProvider value={model}>
                <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" maxWidth={"md"} fullWidth={true}>
                    <DialogTitle id="form-dialog-title">
                        <Conditional condition={model.isNew}>
                            <IfTrue><Trans>Create Operation Code</Trans></IfTrue>
                            <IfFalse><Trans>Edit Operation Code</Trans></IfFalse>
                        </Conditional>
                    </DialogTitle>
                    <DialogContent>
                        <ModelInput name={'code'}/>
                        <ModelSelect name={'display_group'} options={displayOptions}/>
                        <ModelSelect name={'eer_category_id'} options={categoryOptions}/>
                        <ModelInput name={'description'}/>
                        <DialogActions>
                            <Button onClick={handleClose} color={"secondary"}>{t`Close`}</Button>
                            <Button onClick={e => handleSubmit(model)} color={"secondary"} disabled={!model.viewModel.isValid}>{t`Submit`}</Button>
                        </DialogActions>
                    </DialogContent>
                </Dialog>
            </ModelProvider>
        </div>
    )
});
