import {observer} from "mobx-react-lite";
import * as React from "react";
import {DateField, DateFieldProps, WorkstationDateTimePickerWrapper} from "@rx-suite/ui";
import {Moment} from "moment";
import {LinearProgress} from "@material-ui/core";
import {Model} from "@rx-suite/data";

export type ExternalValidation = {
    model: Model,
    name: string,
    checkWithExternal: () => Promise<boolean>,
    errorMessage: string,
    setExternalError?: (bool: boolean) => void
}

type DateTimePickerWithExternalValidationProps = ExternalValidation & DateFieldProps

export const DateTimePickerWithExternalValidation: React.FunctionComponent<DateTimePickerWithExternalValidationProps> = observer(({model, name, checkWithExternal, errorMessage, setExternalError, ...props}) => {
    const [internalError, setInternalError] = React.useState<undefined | string>(undefined);
    const label = props.label || model.label(name)

    const validate_date = async (date: string | Moment) => {
        model.nestedAssignment(name, date);
        const valid = await checkWithExternal();
        if (!valid) {
            setInternalError(errorMessage);
            if(setExternalError) {
                setExternalError(true);
            }
            return
        }
        setInternalError(undefined);
        if(setExternalError) {
            setExternalError(false);
        }
    }

    return (
        <>
            <WorkstationDateTimePickerWrapper onChange={validate_date} error={model.store.fetchErr || internalError} value={model.viewModel[name] as Date} label={label} closeOnSelect {...props} disabled={model.store.isLoading}/>
            {model.store.isLoading && <LinearProgress/>}
        </>
    )
})