import * as React from "react";
import {observer} from "mobx-react-lite";
import {SelectField} from "@rx-suite/ui";
import {SelectFieldProps} from "@rx-suite/ui/lib/components/base/SelectField";
import {ExternalValidation} from "./DateTimePickerWithExternalValidation";

type ModelInputWithValidationProps = ExternalValidation & Omit<SelectFieldProps, 'value'>

export const ModelSelectWithExternalValidation: React.FunctionComponent<ModelInputWithValidationProps> = observer(({model, name, checkWithExternal, errorMessage, setExternalError, onChange, ...props}) => {
    const [internalError, setInternalError] = React.useState<undefined | string>(undefined);
    const label = props.label || model.label(name);

    const validate_with_external = async (e: any, value: string) => {
        if(onChange) {
            onChange(e, value);
        }
        model.nestedAssignment(name, value);
        const valid = await checkWithExternal();
        if (!valid) {
           setInternalError(errorMessage);
           if(setExternalError) {
               setExternalError(true);
           }
            return
        }
        setInternalError(undefined);
        if(setExternalError) {
           setExternalError(false);
        }
    }

    return (
        <SelectField
            onChange={validate_with_external}
            value={model.viewModel[name]}
            label={label}
            error={!!internalError}
            helperText={internalError}
            loading={model.store.isLoading}
            disabled={model.store.isLoading}
            {...props}
        />
    )
})