import * as React from "react";
import {BreadModel, makeColumn} from "@rx-suite/ui";
import {t} from "@lingui/macro"
import {EerCategoryModel, EerCategoryStore} from "../../stores/EerCategoryStore";
import {EerCategoryForm} from "./EerCategoryForm";
import {EerCategoryColorPicker} from "../../components/eer_category/EerCategoryColorPicker";
import {Observer} from "mobx-react-lite";

export const EerCategoriesBreadModel = () => {
     const columns = [
        makeColumn('name', t`Name`, "string"),
        {
            Header: t`Color`,
            id: 'color',
            accessor: (model: EerCategoryModel) => model,
            Cell: (row: { original: EerCategoryModel | null | undefined }) => {
                return (
                    <Observer>
                        {
                            () => {
                                if (!row.original) {
                                    return <></>;
                                }
                                return <EerCategoryColorPicker model={row.original} includeLabel={false}/>
                            }
                        }
                    </Observer>
                )
            },
            filterable: false,
            sortable: false,
        }
    ]

    return (
        <BreadModel
            store={EerCategoryStore}
            Form={EerCategoryForm}
            columns={columns}
            mountCreate={false}
            tableProps={
                {
                    replacementActions: {
                        Delete: () => null
                    }
                }
            }
        />
    )
}