import * as React from 'react'
import {EerTrackingStationModel, EerTrackingStationStore} from "../../stores/EerTrackingStationStore";
import {makeColumn, ModelTable, PaddedPaper} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {MachineNameBadge} from "../../components/generic/MachineNameBadge";
import {WorkstationLockoutStatus} from "../../components/engineering_lockout/WorkstationLockoutStatus";
import {EngineeringLockoutButton} from "../../components/err_tracking_workstation/panels/machine_info_panel/EngineeringLockoutButton";

export const EngineeringLockoutTable = ()  => {
    const columns = React.useMemo( () => {
        return [
            makeColumn('name', t`Station Name`, 'string'),
            {
                Header: t`Machine`,
                id: 'rx_data_machine_id',
                accessor: (model: EerTrackingStationModel) => model,
                Cell: (cellInfo: { value: EerTrackingStationModel }) => {
                    return <MachineNameBadge machineId={cellInfo.value.rx_data_machine_id}/>
                },
                filterable: false,
                sortable: false,
            },
            {
                Header: t`In Lockout?`,
                id: 'locked',
                accessor: (model: EerTrackingStationModel) => model,
                Cell: (cellInfo: { value: EerTrackingStationModel }) => {
                    return <WorkstationLockoutStatus currentEvent={cellInfo.value.current_event} />
                }
            },
            {
                Header: t`Engineering  Lock`,
                id: 'engineer_lock',
                accessor: (model: EerTrackingStationModel) => model,
                Cell: (cellInfo: { value: EerTrackingStationModel }) => {
                    return <EngineeringLockoutButton station={cellInfo.value}/>

                }
            },
        ]
    }, []);

    return (
        <PaddedPaper>
            <ModelTable
                store={EerTrackingStationStore}
                columns={columns}
                showCreateButton={false}
                suppressWrapper
                suppressActionColumn
                noLinkColumns={['name','rx_data_machine_id', 'locked', 'engineer_lock']}
            />
        </PaddedPaper>

    )
}