import * as React from "react";
import {
    Conditional,
    IfFalse,
    IfTrue,
    LinkButton,
    ModelProvider,
    PaddedPaper
} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Box, createStyles, Divider, Grid, makeStyles, Theme, Typography} from "@material-ui/core";
import {BoxCoaterEventModel} from "../../stores/BoxCoaterEventStore";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {BoxCoaterEvenFormDoorOpened} from "../../components/box_coater_events/form/BoxCoaterEventFormDoorOpened";
import {BoxCoaterEvenFormDoorClosed} from "../../components/box_coater_events/form/BoxCoaterEventFormDoorClosed";
import {MachineNameBadge} from "../../components/generic/MachineNameBadge";
import MenuOpen from "@material-ui/icons/MenuOpen";
import {t} from "@lingui/macro";
import {BoxCoaterEvenFormSubmitButton} from "../../components/box_coater_events/form/BoxCoaterEventFormSubmitButton";
import {BreadModelActionBadges} from "../../components/box_coater_events/bread_model/BreadModelActionBadges";

interface BoxCoaterEventFormProps {
    model: BoxCoaterEventModel
}

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        divider: {
            marginTop: theme.spacing(1),
            marginBottom: theme.spacing(1)
        },
        gridWrapper: {
            maxWidth: '550px',
            marginLeft: theme.spacing(2)
        }
    })
);

export const BoxCoaterEventForm: React.FunctionComponent<BoxCoaterEventFormProps> = observer(({model}) => {
    const classes = useStyles();
    const settings = SystemSettingStore.selectedModel as SystemSettingModel;

    return (
        <PaddedPaper>
            <Box mb={2}>
                <LinkButton to={model.listLink as string} color={"primary"} noGutter><MenuOpen/>{t`All Events`}</LinkButton>
            </Box>
            <Typography variant={"h4"}>{model.resolved_event_type.toUpperCase()}</Typography>
            <Typography variant={"subtitle1"}>{settings.printDateTime(model.time)} ({model.resolved_duration})</Typography>
            <MachineNameBadge machineId={model.machine_id}/>
            <Divider className={classes.divider}/>
            <Conditional condition={model.is_engineering_lockout_event}>
                <IfTrue>
                    <></>
                </IfTrue>
                <IfFalse>
                    <Grid container direction={'column'} className={classes.gridWrapper}>
                        <Conditional condition={model.is_door_open_event}>
                            <IfTrue>
                                <BoxCoaterEvenFormDoorOpened model={model}/>
                            </IfTrue>
                            <IfFalse>
                                <BoxCoaterEvenFormDoorClosed model={model}/>
                            </IfFalse>
                        </Conditional>
                        <Box mb={2}></Box>
                        <BoxCoaterEvenFormSubmitButton model={model}/>
                    </Grid>
                </IfFalse>
            </Conditional>
        </PaddedPaper>
    )
})
