import * as React from "react";
import {CheckboxField, FormProps, ModelForm, ModelInput, WorkstationHelper, WorkstationGenericWrapper} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {YieldModel, YieldStore} from "../../stores/YieldStore";
import {ChangeEvent, SyntheticEvent} from "react";
import {ModelSelectRxDataMachine} from "../../components/yields/ModelSelectLoadOnLoading";
import {MachineModel, MachineStore} from "../../stores/MachineStore";
import {LinearProgress} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {DateTimePickerWithExternalValidation} from "../../components/yields/DateTimePickerWithExternalValidation";

export const YieldForm: React.FunctionComponent<FormProps> = observer(() => {
    const [multiDate, setMultiDate] = React.useState<boolean>(false);
    const [yieldModel, setYieldModel] = React.useState<YieldModel>(YieldStore.createModel());
    let isOverwritingExistingYield = false;
    const machines = MachineStore.getAll();

    if(MachineStore.isLoading) {
        return <LinearProgress/>
    }

    const machineOptions = machines.map((machine: MachineModel) => {return {label: machine.sn, value: machine.id}})

    const multiDateOnChange = (e: ChangeEvent, b: boolean) => {
        setMultiDate(b);
        yieldModel.viewModel.end_date = null;
    }

    const handleSubmitOnClick = () => {
        if(isOverwritingExistingYield) {
            if (!window.confirm(`${t`One or more of the selected dates already have a yield. Do you want to overwrite those entries?`}` )) {
                return false;
            }
        }
        return true;
    }

    const resetYieldModel = (e: SyntheticEvent, resp: any) => {
        setYieldModel(YieldStore.createModel());
    }

    const setIsOverwritingYield = (yieldExists:boolean) => {
        isOverwritingExistingYield = yieldExists;
    }

    return (
        <WorkstationHelper stores={[MachineStore]}>
            <ModelForm model={yieldModel} confirmSubmit={handleSubmitOnClick} afterSubmit={resetYieldModel} suppressMakeCopy suppressImportExport maxWidth={'xl'}>
                <ModelInput name={'value'}/>
                <ModelSelectRxDataMachine
                    name={'machine_ids'}
                    options={machineOptions}
                    onBlur={async () => await yieldModel.validate_yield()}
                    store={YieldStore}
                    multiple
                />
                <DateTimePickerWithExternalValidation
                    model={yieldModel}
                    name={'start_date'}
                    checkWithExternal={async () => await yieldModel.validate_yield()}
                    errorMessage={t`Warning: A yield for this date already exists.`}
                    setExternalError={setIsOverwritingYield}
                    timeFormat={false}
                />
                <div>
                    <CheckboxField onChange={(e,b) => multiDateOnChange(e,b)} label={t`Yield for Multiple Days?`}/>
                </div>
                {multiDate && <WorkstationGenericWrapper>
                    <DateTimePickerWithExternalValidation
                        model={yieldModel}
                        name={'end_date'}
                        checkWithExternal={async () => yieldModel.validate_yield()}
                        errorMessage={t`Warning: A yield already exist for one or more days in the selected date range.`}
                        setExternalError={setIsOverwritingYield}
                        timeFormat={false}
                    />
                </WorkstationGenericWrapper>}
            </ModelForm>
        </WorkstationHelper>
    )
});