import {dataStorePermission} from "@rx-suite/ui";
import {
    AddComment,
    SubdirectoryArrowRight,
    Category,
    Timer, AssignmentLate, CalendarToday, Lock
} from '@material-ui/icons';
import {OperatorNoteGroupStore} from "./stores/OperatorNoteGroupStore";
import {OperatorNoteGroupsBreadModel} from "./pages/operator_note_groups/OperatorNoteGroupsBreadModel";
import {EerTrackingStationStore} from "./stores/EerTrackingStationStore";
import {EerTrackingStationsBreadModel} from "./pages/eer_tracking_stations/settings/EerTrackingStationsBreadModel";
import React from "react";
import {computedFn} from "mobx-utils";
import {EerCategoriesBreadModel} from "./pages/eer_categories/EerCategoriesBreadModel";
import {YieldStore} from "./stores/YieldStore";
import {YieldForm} from "./pages/yields/YieldForm";
import {t} from "@lingui/macro";
import SettingsIcon from '@material-ui/icons/Settings';
import {EerCategoryStore} from "./stores/EerCategoryStore";
import {BoxCoaterEventsBreadModel} from "./pages/events/BoxCoaterEventsBreadModel";
import {EerTrackingWorkstation} from "./pages/eer_tracking_stations/workstation/EerTrackingWorkstation";
import {EngineeringLockoutTable} from "./pages/engineering_lockout/EngineeringLockoutTable";

export const getRoutes = computedFn(() => {
    return [
        {
            label: t`Performance Tracking`,
            to: "/eer_tracking_stations",
            exact: false,
            Icon: Timer,
            children: EerTrackingStationStore.getAll().map( e => (
                {
                    label: e.name,
                    to: `/eer_tracking_station/${e.id}`,
                    permission: {
                        target: `eer_tracking_workstation_${e.id}`,
                        action: 'use'
                    },
                    exact: false,
                    Icon: SubdirectoryArrowRight,
                    Component: () => <EerTrackingWorkstation model={e}/>
                }
            ))
        },
        {
            label: t`Events`,
            to: "/box_coater_events",
            exact: false,
            Component: BoxCoaterEventsBreadModel,
            Icon: AssignmentLate
        },
        {
            label: t`Yields`,
            to: "/yields",
            exact: false,
            permission: dataStorePermission(YieldStore),
            Component: YieldForm,
            Icon: CalendarToday
        },
        {
            label: t`Settings`,
            to: "/settings",
            exact: true,
            Icon: SettingsIcon,
            children: [
                {
                    label: t`Engineering Lockout`,
                    to: "/engineering_lockout",
                    exact: false,
                    permission: {
                        target: 'EerTrackingStation',
                        action: 'engineering_lockout'
                    },
                    Component: EngineeringLockoutTable,
                    Icon: Lock
                },
                {
                    label: t`Performance Tracking`,
                    to: "/eer_tracking_stations",
                    exact: false,
                    permission: dataStorePermission(EerTrackingStationStore),
                    Component: EerTrackingStationsBreadModel,
                    Icon: Timer
                },
                {
                    label: t`Performance Notes`,
                    to: "/operator_note_groups",
                    exact: false,
                    permission: dataStorePermission(OperatorNoteGroupStore),
                    Component: OperatorNoteGroupsBreadModel,
                    Icon: AddComment
                },
                {
                    label: `Reporting Categories`,
                    to: "/eer_categories",
                    exact: false,
                    permission: dataStorePermission(EerCategoryStore),
                    Component: EerCategoriesBreadModel,
                    Icon: Category
                }
            ]
        },
    ]
})
