import {attribute, DataStore, Model, model} from "@rx-suite/data";
import {computed} from "mobx";
import {t} from "@lingui/macro";

export type DomeSide = 'both' | 'CX' | 'CC';

// This is a proxy store for Rx-Data
@model({
    transportLayer: "/api/box_coater_recipes",
})

export class BoxCoaterRecipeModel extends Model {

    @attribute({label: t`Display Name`})
    name: string = '';

    @attribute({label: t`Recipe Code`})
    recipe_code: string = '';

    @attribute({ label: t`Dome Side`})
    dome_side: DomeSide = 'CC';

    @attribute({label: t`Processing Time (in seconds)`})
    processing_time: number = -1;

    @computed
    get resolved_duration() {
        const minutes = this.processing_time / 60;
        return minutes == 1 ? t`1 minute` : t`${minutes} minutes`;
    }

    @computed
    get isConcaveRecipe(): boolean {
        return this.dome_side === 'CC' || this.dome_side === 'both';
    }

    @computed
    get isConvexRecipe(): boolean {
        return this.dome_side === 'CX' || this.dome_side === 'both';
    }

    constructor() {
        super();
        super.setup(); // This registers the observable attributes and viewModel
    }
}

export const BoxCoaterRecipeStore = BoxCoaterRecipeModel.store as unknown as DataStore<BoxCoaterRecipeModel>;