import {attribute, DataStore, model, Model} from "@rx-suite/data";
import {action, computed, observable, override, runInAction} from "mobx";
import moment from "moment";

// This store proxies the same store in Rx-Data and doesn't actual allow editing of any models.

@model({
    transportLayer: "/api/machine_states",
    eager: true
})

export class MachineStateModel extends Model {
    // Note: this is NOT the true machine state ID but instead the machine_id so that
    // when a machine state is updated from cable, it can update the proper model
    @attribute()
    id: number = 0;

    @attribute()
    machine_id: number = 0;

    @attribute()
    state: string = '';

    @attribute()
    comment: string = '';

    @computed
    get resolved_state() {
        return this.state.toUpperCase()
    }

    @override
    get viewDirty() {
        return false;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const MachineStateStore = MachineStateModel.store as DataStore<MachineStateModel>;