import {attribute, DataStore, model, Model} from "@rx-suite/data";
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {computed} from "mobx";

// This store proxies the same store in Rx-Data and doesn't actual allow editing of any models.
@model({
    eager: true,
    transportLayer: "/api/machines"
})

export class MachineModel extends Model {
    @attribute({label: t`Id`, validation: yup.number()})
    id = 0;

    @attribute({label: t`Serial Number`, validation: yup.string()})
    sn = '';

    @attribute({label: t`name`, validation: yup.string()})
    name = '';

    @computed
    get extendedName(): string {
        if (!this.name) {
            return `(${this.sn})`;
        }
        return `${this.name} (${this.sn})`;
    }

    constructor() {
        super();
        super.setup();
    }
}

export const MachineStore = MachineModel.store as DataStore<MachineModel>;