import {attribute, DataStore, Model, model} from "@rx-suite/data";
import * as yup from "yup";
import {t} from "@lingui/macro"
import {computed} from "mobx";

@model({
    transportLayer: "/api/operator_notes"
})

export class OperatorNoteModel extends Model {
    @attribute({label: t`Id`, validation: yup.number()})
    id: number = 0;

    @attribute({label: t`Operation Code`, validation: yup.string().min(3, t`Operation Code must be at least 3 characters`)})
    code: string = '';

    @attribute({label: t`Operator Note Group Id`, validation: yup.number()})
    operator_note_group_id: number = 0;

    @attribute({label: t`Display During`, validation: yup.string()})
    display_group: 'both' | 'closed' | 'open' = 'both';

    @attribute({label: t`Reporting Category`, validation: yup.number().min(0, t`Operator notes must be attached to a reporting category.`).required()})
    eer_category_id: number = -1;

    @attribute({label: t`Description`, validation: yup.string().nullable()})
    description: string | null = null;

    @computed
    get display_during_door_open(){
        return this.display_group === 'both' || this.display_group == 'open';
    }

    @computed
    get display_during_door_closed(){
        return this.display_group === 'both' || this.display_group == 'closed';
    }

    constructor() {
        super();
        super.setup();
    }
}

export const OperatorNoteStore = OperatorNoteModel.store as DataStore<OperatorNoteModel>;