import {attribute, DataStore, Model, model} from "@rx-suite/data";
import * as yup from "yup";
import {t} from "@lingui/macro"
import {action, runInAction} from "mobx";

@model({
    transportLayer: "/api/yields",
    permissionTarget: "Yield",
    routingInfo: {
        create: '/yields/create',
        read: '/yields/:id/edit',
        update: '/yields/:id/edit'
    }
})

export class YieldModel extends Model {
    @attribute({label: t`Id`, validation: yup.number()})
    id: number = 0;

    @attribute({label: t`Yield Value (%)`, validation: yup.number().positive()})
    value: number = 0;

    @attribute({label: t`Start Date`, validation: yup.date().required()})
    start_date: Date | null = null;

    @attribute({label: t`End Date`, validation: yup.date().nullable()})
    end_date: Date | null = null;

    @attribute({label: t`Yield for Machines`, validation: yup.array().min(1)})
    machine_ids: number[] = [];

    @attribute()
    loading: boolean = false;

    @action
    async validate_yield() {
        if(!this.viewModel.start_date) { return true; }
        if(this.viewModel.machine_ids.length < 1) { return true; }
        runInAction(() => {
            this.store.fetching = true;
            this.store.fetchErr = null;
        })
        this.nestedAssignment('loading', true);
        const resp = await fetch(`/api/yields/yield_exists`, {
            method: "POST",
            headers: {'Content-Type': 'application/json'},
            body: JSON.stringify({yield: this.viewModelAsJSON})
        })
        const data = await resp.json();
        runInAction(() => {
            this.store.fetching = false;
        })
        if(!resp.ok) {
            runInAction(() => {
                this.store.fetchErr = 'Unable to validate date. Please check connection to Rx-Data.';
            })
            throw 'Failed to validate yield';
        }
        return !data.yield_exists;
    }

    @action
    async yieldSubmit() {
        const resp = await fetch(`/api/yields/create_yield`, {
            method: "POST",
            headers: {'Content-Type': 'application/json'},
            body: JSON.stringify({yield: this})
        })
        if (!resp.ok) {
            throw 'Failed to create yield';
        }
    }

    constructor() {
        super();
        super.setup();
    }
}

export const YieldStore = YieldModel.store as DataStore<YieldModel>;