# frozen_string_literal: true

# Note this is a proxy model coming from Rx-Data, there is no associated DB table in this module.

class BoxCoaterEvent < ApplicationRecord
  def self.add_requires_action(models)
    models = [models] unless models.is_a? Array

    models.each do |model|
      if model[:duration].nil? || model[:operator_note]
        # If the model has no duration, it's active, let the front end deal with it
        # Otherwise, if the model already has an operator note, do not request another
        model[:requires_operator_note] = false
        next
      end

      model[:requires_operator_note] = case model[:event_type]
                                       when 'door_open'
                                         exceeds_door_open_time?(model)
                                       when 'door_closed'
                                         exceeds_recipe_time?(model)
                                       else
                                         false
                                       end
    end
  end

  private

  def self.exceeds_door_open_time?(model)
    tracking_station = EerTrackingStation.find_by(rx_data_machine_id: model[:machine_id])

    if tracking_station.nil?
      false
    else
      model_duration(model) > tracking_station.door_open_max_time
    end
  end

  def self.exceeds_recipe_time?(model)
    recipe_time = if model[:recipe].nil?
               nil
             else
               model[:processing_time]
             end

    if recipe_time.nil?
      exceeds_door_closed_time?(model)
    else
      model_duration(model) > recipe_time
    end
  end

  def self.exceeds_door_closed_time?(model)
    tracking_station = EerTrackingStation.find_by(rx_data_machine_id: model[:machine_id])

    if tracking_station.nil?
      false
    else
      model_duration(model) > tracking_station.door_closed_max_time
    end
  end

  def self.model_duration(model)
    # For some reason, we receive this as a string from Rx-Data, so cast it to a float
    model[:duration].to_f
  end
end
