# == Schema Information
#
# Table name: eer_tracking_stations
#
#  id                   :bigint           not null, primary key
#  door_closed_max_time :integer          not null
#  door_open_max_time   :integer          not null
#  machine_sn           :string
#  name                 :string
#  rx_data_machine_id   :bigint           not null
#
class EerTrackingStation < ApplicationRecord
  has_many :station_operator_note_groups, dependent: :destroy
  has_many :operator_note_groups, through: :station_operator_note_groups

  class FailedToRegisterExternal < StandardError; end

  class << self
    def current_event_for_machines(machine_ids)
      resp = RxModule::Communicator.call_module_method_internal('rx_data', '/api/box_coater_events/latest_for_machines',
                                                                :put,
                                                                {
                                                                    machine_ids: machine_ids
                                                                  }
                                                                )
      resp[:models]
    rescue StandardError => e
      Rails.logger.error "Failed to load current coater events. Rx-Data returned error: #{e}"
      []
    end
  end

  def event
    @event ||= nil
  end

  def set_event(event)
    @event = event
  end

  def register
    set_track_metric_external(true)
  end

  def unregister
    set_track_metric_external(false)
  end

  def to_json(event=nil)
    controller = controller_name.constantize
    controller.render(assigns: { model: self, event: event }, template: 'eer_tracking_stations/show', layout: false)
  end

  def coater_current_event
    RxModule::Communicator.call_module_method_internal('rx_data', "#{external_url_base}/box_coater_event", :get)
  rescue StandardError => e
    Rails.logger.error "Failed to load current event for station #{name}. Rx-Data returned error: #{e}"
    nil
  end

  def set_engineer_lockout_external(lock)
    RxModule::Communicator.call_module_method('rx_data', "#{external_url_base}/engineering_lockout", :put, { lock: lock })
  rescue StandardError => e
    Rails.logger.error "Failed to set engineering lockout (#{lock}) for tracking station #{name}. Rx-Data returned error: #{e}"
    raise e
  end

  private

  def set_track_metric_external(is_eer_machine)
    resp = RxModule::Communicator.call_module_method_internal('rx_data', "#{external_url_base}/register_as_eer_machine", :put, {is_eer_machine: is_eer_machine})
    raise FailedToRegisterExternal unless resp[:track_eer_metrics] == is_eer_machine
  rescue StandardError => e
    Rails.logger.error "Failed to set track metric (#{is_eer_machine}) for tracking station #{name}. Rx-Data returned error: #{e}"
    raise e
  end

  def external_url_base
    "/api/machines/#{rx_data_machine_id}"
  end
end
